"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.WidgetCodeSelectable = void 0;

var _react = _interopRequireDefault(require("react"));

var _uiSchema = require("@ui-schema/ui-schema");

var _MenuItem = _interopRequireDefault(require("@mui/material/MenuItem"));

var _Select = _interopRequireDefault(require("@mui/material/Select"));

var _CodeBar = require("@ui-schema/material-code/CodeBar");

var _material = require("@mui/material");

var _FormLabel = _interopRequireDefault(require("@mui/material/FormLabel"));

var _LocaleHelperText = require("@ui-schema/ds-material/Component/LocaleHelperText");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var WidgetCodeSelectable = function WidgetCodeSelectable(_ref) {
  var _schema$get;

  var storeKeys = _ref.storeKeys,
      schema = _ref.schema,
      value = _ref.value,
      onChange = _ref.onChange,
      valid = _ref.valid,
      required = _ref.required,
      errors = _ref.errors,
      showValidity = _ref.showValidity,
      readOnlyProp = _ref.readOnly,
      CodeMirror = _ref.CodeMirror,
      extensions = _ref.extensions,
      formatValue = _ref.formatValue,
      formatKey = _ref.formatKey,
      valueKey = _ref.valueKey,
      barContent = _ref.barContent,
      barEnd = _ref.barEnd,
      _ref$selectSize = _ref.selectSize,
      selectSize = _ref$selectSize === void 0 ? 'small' : _ref$selectSize,
      onChangeFormat = _ref.onChangeFormat,
      CustomCodeBar = _ref.CodeBar;

  var handleOnChange = _react["default"].useCallback(function (_editor, newValue, prevValue) {
    if (newValue === prevValue) {
      return;
    }

    onChange({
      storeKeys: storeKeys.push(valueKey),
      scopes: ['value'],
      type: 'set',
      data: {
        value: newValue
      },
      schema: schema,
      required: required
    });
  }, [onChange, storeKeys, schema, required, valueKey]);

  var handleOnChangeFormat = _react["default"].useCallback(function (e) {
    if (onChangeFormat) {
      onChangeFormat(e.target.value);
    }

    onChange({
      storeKeys: storeKeys.push(formatKey),
      scopes: ['value'],
      type: 'set',
      data: {
        value: e.target.value
      },
      schema: schema,
      required: required
    });
  }, [onChange, onChangeFormat, storeKeys, schema, required, formatKey]);

  var hideTitle = schema === null || schema === void 0 ? void 0 : schema.getIn(['view', 'hideTitle']);
  var readOnly = readOnlyProp || (schema === null || schema === void 0 ? void 0 : schema.get('readOnly'));

  var classNamesContent = _react["default"].useMemo(function () {
    return valid ? undefined : ['invalid'];
  }, [valid]);

  var CodeBarComp = CustomCodeBar || _CodeBar.CodeBar;
  return _react["default"].createElement(_react["default"].Fragment, null, hideTitle ? null : _react["default"].createElement(_material.Box, {
    mb: 0.5
  }, _react["default"].createElement(_FormLabel["default"], {
    error: !valid && showValidity
  }, _react["default"].createElement(_uiSchema.TransTitle, {
    storeKeys: storeKeys,
    schema: schema
  }), required ? ' *' : null)), _react["default"].createElement(CodeMirror, {
    value: value || '',
    onChange: readOnly ? undefined : handleOnChange,
    extensions: extensions,
    classNamesContent: classNamesContent
  }), _react["default"].createElement(_LocaleHelperText.ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }), _react["default"].createElement(CodeBarComp, {
    schema: schema,
    barBegin: _react["default"].createElement(_Select["default"], {
      onChange: handleOnChangeFormat,
      value: formatValue || '',
      size: selectSize,
      disabled: readOnly
    }, schema === null || schema === void 0 ? void 0 : (_schema$get = schema.get('format')) === null || _schema$get === void 0 ? void 0 : _schema$get.map(function (f) {
      return _react["default"].createElement(_MenuItem["default"], {
        key: f,
        value: f,
        dense: true
      }, _react["default"].createElement(_uiSchema.Trans, {
        text: 'formats.' + f,
        fallback: f
      }));
    })),
    barContent: barContent,
    barEnd: barEnd
  }));
};

exports.WidgetCodeSelectable = WidgetCodeSelectable;