import React from 'react';
import { Trans, TransTitle } from '@ui-schema/ui-schema';
import { CodeBar } from '@ui-schema/material-code/CodeBar';
import { Box } from '@mui/material';
import FormLabel from '@mui/material/FormLabel';
import { ValidityHelperText } from '@ui-schema/ds-material/Component/LocaleHelperText';
export const WidgetCode = ({
  storeKeys,
  schema,
  value,
  onChange,
  valid,
  required,
  errors,
  showValidity,
  readOnly: readOnlyProp,
  CodeMirror,
  extensions,
  barBegin,
  barContent,
  barEnd,
  formatValue,
  CodeBar: CustomCodeBar
}) => {
  const handleOnChange = React.useCallback((_editor, newValue, prevValue) => {
    if (newValue === prevValue) {
      return;
    }

    onChange({
      storeKeys,
      scopes: ['value'],
      type: 'set',
      data: {
        value: newValue
      },
      schema,
      required
    });
  }, [onChange, storeKeys, schema, required]);
  const hideTitle = schema === null || schema === void 0 ? void 0 : schema.getIn(['view', 'hideTitle']);
  const readOnly = readOnlyProp || (schema === null || schema === void 0 ? void 0 : schema.get('readOnly'));
  const classNamesContent = React.useMemo(() => valid ? undefined : ['invalid'], [valid]);
  const CodeBarComp = CustomCodeBar || CodeBar;
  return React.createElement(React.Fragment, null, React.createElement(Box, {
    mb: 0.5
  }, React.createElement(FormLabel, {
    error: !valid && showValidity
  }, hideTitle ? null : React.createElement(React.Fragment, null, React.createElement(TransTitle, {
    storeKeys: storeKeys,
    schema: schema
  }), required ? ' *' : null), formatValue ? React.createElement(React.Fragment, null, hideTitle ? null : ' (', React.createElement(Trans, {
    text: 'formats.' + formatValue,
    fallback: formatValue
  }), hideTitle ? null : ')') : null)), React.createElement(CodeMirror, {
    value: value || '',
    onChange: readOnly ? undefined : handleOnChange,
    extensions: extensions,
    classNamesContent: classNamesContent
  }), React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }), React.createElement(CodeBarComp, {
    schema: schema,
    barBegin: barBegin,
    barContent: barContent,
    barEnd: barEnd
  }));
};